<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv_SE">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
</context>
<context>
    <name>BatchTranslationDialog</name>
    <message>
        <source>Qt Linguist - Batch Translation</source>
        <translation>Qt Linguist - Mängdöversättning</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Alternativ</translation>
    </message>
    <message>
        <source>Set translated entries to finished</source>
        <translation>Ange översatta poster som slutförda</translation>
    </message>
    <message>
        <source>Retranslate entries with existing translation</source>
        <translation>Återöversätt poster med befintlig översättning</translation>
    </message>
    <message>
        <source>Note that the modified entries will be reset to unfinished if &apos;Set translated entries to finished&apos; above is unchecked</source>
        <translation>Notera att ändrade poster kommer att nollställas till oavslutade, om &quot;Ange översatta poster som färdiga&quot; är avmarkerat</translation>
    </message>
    <message>
        <source>Translate also finished entries</source>
        <translation>Översätt även slutförda poster</translation>
    </message>
    <message>
        <source>Phrase book preference</source>
        <translation>Ordboksinställning</translation>
    </message>
    <message>
        <source>Move up</source>
        <translation>Flytta upp</translation>
    </message>
    <message>
        <source>Move down</source>
        <translation>Flytta ner</translation>
    </message>
    <message>
        <source>The batch translator will search through the selected phrase books in the order given above</source>
        <translation>Mängdöversättaren kommer att söka igenom de valda ordböckerna i den ordning som anges ovan</translation>
    </message>
    <message>
        <source>&amp;Run</source>
        <translation>&amp;Kör</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Batch Translation of &apos;%1&apos; - Qt Linguist</source>
        <translation>Mängdöversättning av &quot;%1&quot; - Qt Linguist</translation>
    </message>
    <message>
        <source>Searching, please wait...</source>
        <translation>Säker, vänta lite...</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Linguist batch translator</source>
        <translation>Linguist mängdöversättare</translation>
    </message>
    <message numerus="yes">
        <source>Batch translated %n entries</source>
        <translation>
            <numerusform>Mängdöversatte %n post</numerusform>
            <numerusform>Mängdöversatte %n poster</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DataModel</name>
    <message>
        <source>The translation file &apos;%1&apos; will not be loaded because it is empty.</source>
        <translation>Översättningsfilen &quot;%1&quot; kommer inte att läsas in, eftersom den är tom.</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Duplicate messages found in &apos;%1&apos;:</source>
        <translation>&lt;qt&gt;Dubblettmeddelanden hittades i &quot;%1&quot;:</translation>
    </message>
    <message>
        <source>&lt;p&gt;[more duplicates omitted]</source>
        <translation>&lt;p&gt;[flera dubbletter utelämnade]</translation>
    </message>
    <message>
        <source>&lt;p&gt;* ID: %1</source>
        <translation>&lt;p&gt;* ID: %1</translation>
    </message>
    <message>
        <source>&lt;p&gt;* Context: %1&lt;br&gt;* Source: %2</source>
        <translation>&lt;p&gt;* Kontext: %1&lt;br&gt;* Källa: %2</translation>
    </message>
    <message>
        <source>&lt;br&gt;* Comment: %3</source>
        <translation>&lt;br&gt;* Kommentar: %3</translation>
    </message>
    <message>
        <source>Linguist does not know the plural rules for &apos;%1&apos;.
Will assume a single universal form.</source>
        <translation>Linguist känner inte till pluralreglerna för &quot;%1&quot;.
Kommer att anta en enskild universell form.</translation>
    </message>
    <message>
        <source>Cannot create &apos;%2&apos;: %1</source>
        <translation>Kan inte skapa &quot;%2&quot;: %1</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <extracomment>&lt;language&gt; (&lt;territory&gt;)</extracomment>
        <translation>%1 (%2)</translation>
    </message>
    <message>
        <source>Universal Form</source>
        <translation>Universell form</translation>
    </message>
</context>
<context>
    <name>ErrorsView</name>
    <message>
        <source>Accelerator possibly superfluous in translation.</source>
        <translation>Accelerator eventuellt överflödig i översättningen.</translation>
    </message>
    <message>
        <source>Accelerator possibly missing in translation.</source>
        <translation>Accelerator saknas eventuellt i översättningen.</translation>
    </message>
    <message>
        <source>Translation does not have same leading and trailing whitespace as the source text.</source>
        <translation>Översättningen har inte samma inledande och avslutande blanksteg som källtexten.</translation>
    </message>
    <message>
        <source>Translation does not end with the same punctuation as the source text.</source>
        <translation>Översättningen slutar inte med samma skiljetecken som källtexten.</translation>
    </message>
    <message>
        <source>A phrase book suggestion for &apos;%1&apos; was ignored.</source>
        <translation>Ett ordboksförslag för &quot;%1&quot; ignorerades.</translation>
    </message>
    <message>
        <source>Translation does not refer to the same place markers as in the source text.</source>
        <translation>Översättningen refererar inte till samma platsmarkörer som i källtexten.</translation>
    </message>
    <message>
        <source>Translation does not contain the necessary %n/%Ln place marker.</source>
        <translation>Översättningen innehåller inte de nödvändiga platsmarkörerna %n/%Ln.</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Okänt fel</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>Sök</translation>
    </message>
    <message>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation>Detta fönster låter dig söka efter text i översättningens källfil.</translation>
    </message>
    <message>
        <source>&amp;Find what:</source>
        <translation>&amp;Sök efter:</translation>
    </message>
    <message>
        <source>Type in the text to search for.</source>
        <translation>Skriv in text att söka efter.</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Alternativ</translation>
    </message>
    <message>
        <source>Lets you use a Perl-compatible regular expression</source>
        <translation>Låter dig använda en Perl-kompatibel regular expression</translation>
    </message>
    <message>
        <source>Regular &amp;expression</source>
        <translation>Regular &amp;expression</translation>
    </message>
    <message>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation>Text såsom &quot;TeX&quot; och &quot;tex&quot; betraktas som olika om markerad.</translation>
    </message>
    <message>
        <source>&amp;Match case</source>
        <translation>Skiftl&amp;ägeskänslig</translation>
    </message>
    <message>
        <source>Source texts are searched when checked.</source>
        <translation>Källtexter genomsöks vid markering.</translation>
    </message>
    <message>
        <source>&amp;Source texts</source>
        <translation>&amp;Källtexter</translation>
    </message>
    <message>
        <source>Obsoleted messages are skipped when checked.</source>
        <translation>Föråldrade meddelanden undantas om markerad.</translation>
    </message>
    <message>
        <source>Skip &amp;obsolete</source>
        <translation>&amp;Undanta föråldrade</translation>
    </message>
    <message>
        <source>Comments and contexts are searched when checked.</source>
        <translation>Kommentarer och kontext genomsöks vid markering.</translation>
    </message>
    <message>
        <source>&amp;Comments</source>
        <translation>K&amp;ommentarer</translation>
    </message>
    <message>
        <source>Ignore &amp;accelerators</source>
        <translation>Ignorera &amp;acceleratorer</translation>
    </message>
    <message>
        <source>Translations are searched when checked.</source>
        <translation>Översättningar genomsöks vid markering.</translation>
    </message>
    <message>
        <source>&amp;Translations</source>
        <translation>&amp;Översättningar</translation>
    </message>
    <message>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation>Klicka här för att hitta nästa förekomst av den text du söker.</translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation>Sök nästa</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>Klicka här för att stänga detta fönster.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source></source>
        <comment>Choose Edit|Find from the menu bar or press Ctrl+F to pop up the Find dialog</comment>
        <translation></translation>
    </message>
    <message>
        <source>T&amp;ranslation status:</source>
        <translation>Ö&amp;versättningsstatus:</translation>
    </message>
    <message>
        <source>Lets you filter the search target by translation status</source>
        <translation>Låter dig filtrera sökningsmålet efter översättningsstatus</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alla</translation>
    </message>
    <message>
        <source>Finished</source>
        <translation>Färdiga</translation>
    </message>
    <message>
        <source>Unfinished</source>
        <translation>Oavslutade</translation>
    </message>
</context>
<context>
    <name>FormMultiWidget</name>
    <message>
        <source>Alt+Delete</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Alt+Delete</translation>
    </message>
    <message>
        <source>Shift+Alt+Insert</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Shift+Alt+Insert</translation>
    </message>
    <message>
        <source>Alt+Insert</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Alt+Insert</translation>
    </message>
    <message>
        <source>Confirmation - Qt Linguist</source>
        <translation>Bekräftelse - Qt Linguist</translation>
    </message>
    <message>
        <source>Delete non-empty length variant?</source>
        <translation>Vill du ta bort icke tomma längdvarianter?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation>Huvudfönster</translation>
    </message>
    <message>
        <source>&amp;Phrases</source>
        <translation>&amp;Fraser</translation>
    </message>
    <message>
        <source>&amp;Close Phrase Book</source>
        <translation>&amp;Stäng ordbok</translation>
    </message>
    <message>
        <source>&amp;Edit Phrase Book</source>
        <translation>&amp;Redigera ordbok</translation>
    </message>
    <message>
        <source>&amp;Print Phrase Book</source>
        <translation>S&amp;kriv ut ordbok</translation>
    </message>
    <message>
        <source>V&amp;alidation</source>
        <translation>Va&amp;lidering</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Visa</translation>
    </message>
    <message>
        <source>Vie&amp;ws</source>
        <translation>V&amp;yer</translation>
    </message>
    <message>
        <source>&amp;Toolbars</source>
        <translation>V&amp;erktygsfält</translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation>&amp;Zoom</translation>
    </message>
    <message>
        <source>Guesses</source>
        <translation>Gissningar</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjälp</translation>
    </message>
    <message>
        <source>&amp;Translation</source>
        <translation>&amp;Översättning</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Arkiv</translation>
    </message>
    <message>
        <source>Recently Opened &amp;Files</source>
        <translation>Tidigare öppnade &amp;filer</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Redigera</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Öppna...</translation>
    </message>
    <message>
        <source>Open a Qt translation source file (TS file) for editing</source>
        <translation>Öppna en Qt översättningsfil (TS-fil) för redigering</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>A&amp;vsluta</translation>
    </message>
    <message>
        <source>Close this window and exit.</source>
        <translation>Stäng detta fönster och avsluta.</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <source>Save changes made to this Qt translation source file</source>
        <translation>Spara ändringar gjorda i denna Qt översättningsfil</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>S&amp;para som...</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Spara som...</translation>
    </message>
    <message>
        <source>Save changes made to this Qt translation source file into a new file.</source>
        <translation>Spara ändringar gjorda i denna Qt översättningsfil, i en ny fil.</translation>
    </message>
    <message>
        <source>Release</source>
        <translation>Kompilera</translation>
    </message>
    <message>
        <source>Create a Qt message file suitable for released applications from the current message file.</source>
        <translation>Skapa en QT meddelandefil, passande för publicerade program, från den aktuella meddelandefilen.</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Skriv &amp;ut...</translation>
    </message>
    <message>
        <source>Print a list of all the translation units in the current translation source file.</source>
        <translation>Skriv ut en lista med alla översättningsposter i den aktuella översättningsfilen.</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Ångra</translation>
    </message>
    <message>
        <source>Undo the last editing operation performed on the current translation.</source>
        <translation>Ångra den senaste redigeringen av aktuell översättningspost.</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Upprepa</translation>
    </message>
    <message>
        <source>Redo an undone editing operation performed on the translation.</source>
        <translation>Upprepa en ångrad redigering i översättningen.</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Kli&amp;pp ut</translation>
    </message>
    <message>
        <source>Copy the selected translation text to the clipboard and deletes it.</source>
        <translation>Kopiera markerad översättningstext till urklipp och tar bort den.</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>K&amp;opiera</translation>
    </message>
    <message>
        <source>Copy the selected translation text to the clipboard.</source>
        <translation>Kopiera markerad översättningstext till urklipp.</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Klistra in</translation>
    </message>
    <message>
        <source>Paste the clipboard text into the translation.</source>
        <translation>Klistra in urklippstext i översättningen.</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>&amp;Markera allt</translation>
    </message>
    <message>
        <source>Select the whole translation text.</source>
        <translation>Markera hela översättningstexten.</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Sök...</translation>
    </message>
    <message>
        <source>Search for some text in the translation source file.</source>
        <translation>Sök efter text i översättningsfilen.</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Sök &amp;nästa</translation>
    </message>
    <message>
        <source>Continue the search where it was left.</source>
        <translation>Fortsätt sökningen från senaste träff.</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Prev Unfinished</source>
        <translation>&amp;Föregående oavslutade</translation>
    </message>
    <message>
        <source>Previous unfinished item</source>
        <translation>Föregående oavslutade post</translation>
    </message>
    <message>
        <source>Move to the previous unfinished item.</source>
        <translation>Flytta till föregående oavslutade post.</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Next Unfinished</source>
        <translation>&amp;Nästa oavslutade</translation>
    </message>
    <message>
        <source>Next unfinished item</source>
        <translation>Nästa oavslutade post</translation>
    </message>
    <message>
        <source>Move to the next unfinished item.</source>
        <translation>Flytta till nästa oavslutade post.</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>P&amp;rev</source>
        <translation>F&amp;öregående</translation>
    </message>
    <message>
        <source>Move to previous item</source>
        <translation>Flytta till föregående post</translation>
    </message>
    <message>
        <source>Move to the previous item.</source>
        <translation>Flytta till föregående post.</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Ne&amp;xt</source>
        <translation>N&amp;ästa</translation>
    </message>
    <message>
        <source>Next item</source>
        <translation>Nästa post</translation>
    </message>
    <message>
        <source>Move to the next item.</source>
        <translation>Flytta till nästa post.</translation>
    </message>
    <message>
        <source>Ctrl+Shift+J</source>
        <translation>Ctrl+Shift+J</translation>
    </message>
    <message>
        <source>&amp;Done and Next</source>
        <translation>&amp;Slutför och nästa</translation>
    </message>
    <message>
        <source>Mark item as done and move to the next unfinished item</source>
        <translation>Markera posten som slutförd och fortsätt till nästa oavslutade post</translation>
    </message>
    <message>
        <source>Mark this item as done and move to the next unfinished item.</source>
        <translation>Markera denna post som slutförd och fortsätt till nästa oavslutade post.</translation>
    </message>
    <message>
        <source>Copy from source text</source>
        <translation>Kopiera från källtext</translation>
    </message>
    <message>
        <source>Copies the source text into the translation field</source>
        <translation>Kopiera källtexten till översättningsfältet</translation>
    </message>
    <message>
        <source>Copies the source text into the translation field.</source>
        <translation>Kopiera källtexten till översättningsfältet.</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>&amp;Accelerators</source>
        <translation>&amp;Acceleratorer</translation>
    </message>
    <message>
        <source>Toggles the validity check of accelerators, i.e. whether the number of ampersands in the source and translation text is the same. If the check fails, a message is shown in the warnings window.</source>
        <translation>Validering av acceleratorer, t.ex. om antalet et-tecken i käll- och översättningstexten är desamma. Om kontrollen misslyckas visas ett meddelande i varningsfönstret.</translation>
    </message>
    <message>
        <source>Surrounding &amp;Whitespace</source>
        <translation>&amp;Omgivande blanksteg</translation>
    </message>
    <message>
        <source>Toggles the validity check of surrounding whitespace.</source>
        <translation>Validering av omgivande blanksteg.</translation>
    </message>
    <message>
        <source>Toggles the validity check of surrounding whitespace. If the check fails, a message is shown in the warnings window.</source>
        <translation>Validering av omgivande blanksteg. Om kontrollen misslyckas visas ett meddelande i varningsfönstret.</translation>
    </message>
    <message>
        <source>&amp;Ending Punctuation</source>
        <translation>A&amp;vslutande skiljetecken</translation>
    </message>
    <message>
        <source>Toggles the validity check of ending punctuation</source>
        <translation>Validering av avslutande skiljetecken</translation>
    </message>
    <message>
        <source>Toggles the validity check of ending punctuation. If the check fails, a message is shown in the warnings window.</source>
        <translation>Validering av avslutande skiljetecken. Om kontrollen misslyckas visas ett meddelande i varningsfönstret.</translation>
    </message>
    <message>
        <source>&amp;Phrase matches</source>
        <translation>&amp;Frasmatchning</translation>
    </message>
    <message>
        <source>Toggles checking that phrase suggestions are used</source>
        <translation>Kontrollera om frasförslag används</translation>
    </message>
    <message>
        <source>Toggles checking that phrase suggestions are used. If the check fails, a message is shown in the warnings window.</source>
        <translation>Kontrollera om frasförslag används. Om kontrollen misslyckas visas ett meddelande i varningsfönstret.</translation>
    </message>
    <message>
        <source>Place &amp;Marker Matches</source>
        <translation>&amp;Platsmarkörmatchning</translation>
    </message>
    <message>
        <source>Toggles the validity check of place markers</source>
        <translation>Validering av platsmarkörer</translation>
    </message>
    <message>
        <source>Toggles the validity check of place markers, i.e. whether %1, %2, ... are used consistently in the source text and translation text. If the check fails, a message is shown in the warnings window.</source>
        <translation>Validering av platsmarkörer, t.ex. om %1, %2, o.s.v, används genomgående i källtext och översättningstext. Om kontrollen misslyckas, visas ett meddelande i varningsfönstret.</translation>
    </message>
    <message>
        <source>&amp;New Phrase Book...</source>
        <translation>&amp;Ny ordbok...</translation>
    </message>
    <message>
        <source>Create a new phrase book.</source>
        <translation>Skapa ny ordbok.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open Phrase Book...</source>
        <translation>&amp;Öppna ordbok...</translation>
    </message>
    <message>
        <source>Open a phrase book to assist translation.</source>
        <translation>Öppna en ordbok för att assistera översättningen.</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>&amp;Reset Sorting</source>
        <translation>&amp;Återställ sortering</translation>
    </message>
    <message>
        <source>Sort the items back in the same order as in the message file.</source>
        <translation>Sortera tillbaka posterna till samma ordning som i meddelandefilen.</translation>
    </message>
    <message>
        <source>&amp;Display guesses</source>
        <translation>Visa &amp;gissningar</translation>
    </message>
    <message>
        <source>Set whether or not to display translation guesses.</source>
        <translation>Ange om gissningar skall visas eller inte.</translation>
    </message>
    <message>
        <source>&amp;Statistics</source>
        <translation>&amp;Statistik</translation>
    </message>
    <message>
        <source>Display translation statistics.</source>
        <translation>Visa översättningsstatistik.</translation>
    </message>
    <message>
        <source>&amp;Manual</source>
        <translation>&amp;Manual</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>About Qt Linguist</source>
        <translation>Om Qt Linguist</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Om Qt</translation>
    </message>
    <message>
        <source>Display information about the Qt toolkit by Digia.</source>
        <translation>Visa information om Qt toolkit av Digia.</translation>
    </message>
    <message>
        <source>&amp;What&apos;s This?</source>
        <translation>&amp;Vad är detta?</translation>
    </message>
    <message>
        <source>What&apos;s This?</source>
        <translation>Vad är detta?</translation>
    </message>
    <message>
        <source>Enter What&apos;s This? mode.</source>
        <translation>Gå in i &quot;Vad är detta?&quot;-läget.</translation>
    </message>
    <message>
        <source>Shift+F1</source>
        <translation>Shift+F1</translation>
    </message>
    <message>
        <source>&amp;Search And Translate...</source>
        <translation>&amp;Sök och översätt...</translation>
    </message>
    <message>
        <source>Replace the translation on all entries that matches the search source text.</source>
        <translation>Ersätt översättningen i alla poster som matchar sökningens källtext.</translation>
    </message>
    <message>
        <source>&amp;Batch Translation...</source>
        <translation>M&amp;ängdöversättning...</translation>
    </message>
    <message>
        <source>Batch translate all entries using the information in the phrase books.</source>
        <translation>Mängdöversätt alla poster med hjälp av informationen i ordböckerna.</translation>
    </message>
    <message>
        <source>Release As...</source>
        <translation>Kompilera som...</translation>
    </message>
    <message>
        <source>Create a Qt message file suitable for released applications from the current message file. The filename will automatically be determined from the name of the TS file.</source>
        <translation>Skapa en QT meddelandefil, passande för publicerade program, från den aktuella meddelandefilen. Filnamnet hämtas automatiskt från namnet på TS-filen.</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Arkiv</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Översättning</translation>
    </message>
    <message>
        <source>Validation</source>
        <translation>Validering</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <source>Open/Refresh Form &amp;Preview</source>
        <translation>Öppna/Uppdatera form&amp;granskning</translation>
    </message>
    <message>
        <source>Form Preview Tool</source>
        <translation>Formgranskningsverktyg</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Translation File &amp;Settings...</source>
        <translation>&amp;Översättningsfilens inställningar...</translation>
    </message>
    <message>
        <source>&amp;Add to Phrase Book</source>
        <translation>&amp;Lägg till i ordbok</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Open Read-O&amp;nly...</source>
        <translation>Öppna &amp;med skrivskydd...</translation>
    </message>
    <message>
        <source>&amp;Save All</source>
        <translation>&amp;Spara alla</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;Release All</source>
        <translation>&amp;Kompilera alla</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <source>&amp;Close All</source>
        <translation>St&amp;äng alla</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Length Variants</source>
        <translation>Längdvarianter</translation>
    </message>
    <message>
        <source>Visualize whitespace</source>
        <translation>Visualisera blanksteg</translation>
    </message>
    <message>
        <source>Increase</source>
        <translation>Öka</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Decrease</source>
        <translation>Minska</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>Återställ standard</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>Show more</source>
        <translation>Visa mer</translation>
    </message>
    <message>
        <source>Alt++</source>
        <translation>Alt++</translation>
    </message>
    <message>
        <source>Show fewer</source>
        <translation>Visa mindre</translation>
    </message>
    <message>
        <source>Alt+-</source>
        <translation>Alt+-</translation>
    </message>
    <message>
        <source>Alt+0</source>
        <translation>Alt+0</translation>
    </message>
    <message>
        <source>D&amp;one</source>
        <translation>Sl&amp;utför</translation>
    </message>
    <message>
        <source>Mark item as done</source>
        <translation>Markera posten som slutförd</translation>
    </message>
    <message>
        <source>Mark this item as done.</source>
        <translation>Markera denna post som slutförd.</translation>
    </message>
    <message>
        <source></source>
        <comment>This is the application&apos;s main window.</comment>
        <translation></translation>
    </message>
    <message>
        <source>Source text</source>
        <translation>Källtext</translation>
    </message>
    <message>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <source>Context</source>
        <translation>Kontext</translation>
    </message>
    <message>
        <source>Items</source>
        <translation>Poster</translation>
    </message>
    <message>
        <source>This panel lists the source contexts.</source>
        <translation>Denna panel listar källkontexterna.</translation>
    </message>
    <message>
        <source>Strings</source>
        <translation>Strängar</translation>
    </message>
    <message>
        <source>Phrases and guesses</source>
        <translation>Fraser och gissningar</translation>
    </message>
    <message>
        <source>Sources and Forms</source>
        <translation>Källor och former</translation>
    </message>
    <message>
        <source>Warnings</source>
        <translation>Varningar</translation>
    </message>
    <message>
        <source> MOD </source>
        <comment>status bar: file(s) modified</comment>
        <translation> MOD </translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Läser in...</translation>
    </message>
    <message>
        <source>Loading File - Qt Linguist</source>
        <translation>Läser in filen - Qt Linguist</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; does not seem to be related to the currently open file(s) &apos;%2&apos;.

Close the open file(s) first?</source>
        <translation>Filen &quot;%1&quot; verkar inte vara relaterad till någon aktuell öppen fil &quot;%2&quot;.

Vill du stänga öppna filer först?</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; does not seem to be related to the file &apos;%2&apos; which is being loaded as well.

Skip loading the first named file?</source>
        <translation>Filen &quot;%1&quot; verkar inte vara relaterad till &quot;%2&quot;, som också läses in.

Vill du undanta inläsning av den först nämnda filen?</translation>
    </message>
    <message numerus="yes">
        <source>%n translation unit(s) loaded.</source>
        <translation>
            <numerusform>%n översättningsenhet inläst.</numerusform>
            <numerusform>%n översättningsenheter inlästa.</numerusform>
        </translation>
    </message>
    <message>
        <source>Related files (%1);;</source>
        <translation>Relaterade filer (%1);;</translation>
    </message>
    <message>
        <source>Open Translation Files</source>
        <translation>Öppna översättningsfiler</translation>
    </message>
    <message>
        <source>File saved.</source>
        <translation>Filen sparad.</translation>
    </message>
    <message>
        <source>Qt message files for released applications (*.qm)
All files (*)</source>
        <translation>Qt meddelandefiler för publicerade program (*.qm)
Alla filer (*)</translation>
    </message>
    <message>
        <source>File created.</source>
        <translation>Filen skapad.</translation>
    </message>
    <message>
        <source>Printing...</source>
        <translation>Skriver ut...</translation>
    </message>
    <message>
        <source>Context: %1</source>
        <translation>Kontext: %1</translation>
    </message>
    <message>
        <source>finished</source>
        <translation>slutförd</translation>
    </message>
    <message>
        <source>unresolved</source>
        <translation>olöst</translation>
    </message>
    <message>
        <source>obsolete</source>
        <translation>föråldrad</translation>
    </message>
    <message>
        <source>Printing... (page %1)</source>
        <translation>Skriver ut... (sidan %1)</translation>
    </message>
    <message>
        <source>Printing completed</source>
        <translation>Utskrift slutförd</translation>
    </message>
    <message>
        <source>Printing aborted</source>
        <translation>Utskrift stoppad</translation>
    </message>
    <message>
        <source>Search wrapped.</source>
        <translation>Sökningen nådde slutet.</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <source>Cannot find the string &apos;%1&apos;.</source>
        <translation>Kan inte hitta strängen &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Search And Translate in &apos;%1&apos; - Qt Linguist</source>
        <translation>Sök och översätt i &quot;%1&quot; - Qt Linguist</translation>
    </message>
    <message>
        <source>Translate - Qt Linguist</source>
        <translation>Översätt - Qt Linguist</translation>
    </message>
    <message numerus="yes">
        <source>Translated %n entry(s)</source>
        <translation>
            <numerusform>Översatte %n post</numerusform>
            <numerusform>Översatte %n poster</numerusform>
        </translation>
    </message>
    <message>
        <source>No more occurrences of &apos;%1&apos;. Start over?</source>
        <translation>Inga fler förekomster av &quot;%1&quot;. Vill du börja om?</translation>
    </message>
    <message>
        <source>Create New Phrase Book</source>
        <translation>Skapa ny ordbok</translation>
    </message>
    <message>
        <source>Qt phrase books (*.qph)
All files (*)</source>
        <translation>Qt-ordbok (*.qph)
Alla filer (*)</translation>
    </message>
    <message>
        <source>Phrase book created.</source>
        <translation>Ordbok skapad.</translation>
    </message>
    <message>
        <source>Open Phrase Book</source>
        <translation>Öppna ordbok</translation>
    </message>
    <message>
        <source>Qt phrase books (*.qph);;All files (*)</source>
        <translation>Qt-ordböcker (*.qph);;Alla filer (*)</translation>
    </message>
    <message numerus="yes">
        <source>%n phrase(s) loaded.</source>
        <translation>
            <numerusform>%n ordbok inläst.</numerusform>
            <numerusform>%n ordböcker inlästa.</numerusform>
        </translation>
    </message>
    <message>
        <source>Add to phrase book</source>
        <translation>Lägg till i ordbok</translation>
    </message>
    <message>
        <source>No appropriate phrasebook found.</source>
        <translation>Ingen lämplig ordbok hittades.</translation>
    </message>
    <message>
        <source>Adding entry to phrasebook %1</source>
        <translation>Lägger till post i ordboken %1</translation>
    </message>
    <message>
        <source>Select phrase book to add to</source>
        <translation>Välj ordbok att lägga till i</translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translation>Kan inte starta Qt Assistant (%1)</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>Qt Linguist is a tool for adding translations to Qt applications.</source>
        <translation>Qt Linguist är ett verktyg för att lägga till översättningar till Qt-program.</translation>
    </message>
    <message>
        <source>Do you want to save the modified files?</source>
        <translation>Vill du spara ändrade filer?</translation>
    </message>
    <message>
        <source>Do you want to save &apos;%1&apos;?</source>
        <translation>Vill du spara &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Qt Linguist[*]</source>
        <translation>Qt Linguist[*]</translation>
    </message>
    <message>
        <source>%1[*] - Qt Linguist</source>
        <translation>%1[*] - Qt Linguist</translation>
    </message>
    <message>
        <source>No untranslated translation units left.</source>
        <translation>Inga oöversatta översättningsposter kvar.</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fönster</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimera</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Display the manual for %1.</source>
        <translation>Visa manualen för %1.</translation>
    </message>
    <message>
        <source>Display information about %1.</source>
        <translation>Visa information om %1.</translation>
    </message>
    <message>
        <source>&amp;Save &apos;%1&apos;</source>
        <translation>&amp;Spara &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Save &apos;%1&apos; &amp;As...</source>
        <translation>S&amp;para &quot;%1&quot; som...</translation>
    </message>
    <message>
        <source>Release &apos;%1&apos;</source>
        <translation>Kompilera &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Release &apos;%1&apos; As...</source>
        <translation>Kompilera &quot;%1&quot; som...</translation>
    </message>
    <message>
        <source>&amp;Close &apos;%1&apos;</source>
        <translation>S&amp;täng &quot;%1&quot;</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Spara</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>S&amp;täng</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Spara alla</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Stäng alla</translation>
    </message>
    <message>
        <source>&amp;Release</source>
        <translation>&amp;Kompilera</translation>
    </message>
    <message>
        <source>Translation File &amp;Settings for &apos;%1&apos;...</source>
        <translation>&amp;Filinställningar för &quot;%1&quot;...</translation>
    </message>
    <message>
        <source>&amp;Batch Translation of &apos;%1&apos;...</source>
        <translation>&amp;Mängdöversättning av &quot;%1&quot;...</translation>
    </message>
    <message>
        <source>Search And &amp;Translate in &apos;%1&apos;...</source>
        <translation>S&amp;ök och översätt i &quot;%1&quot;...</translation>
    </message>
    <message>
        <source>Search And &amp;Translate...</source>
        <translation>Sök oc&amp;h översätt...</translation>
    </message>
    <message>
        <source>Cannot read from phrase book &apos;%1&apos;.</source>
        <translation>Kan inte läsa från ordbok &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Close this phrase book.</source>
        <translation>Stäng denna ordbok.</translation>
    </message>
    <message>
        <source>Enables you to add, modify, or delete entries in this phrase book.</source>
        <translation>Låter dig lägga till, ändra eller ta bort poster i denna ordbok.</translation>
    </message>
    <message>
        <source>Print the entries in this phrase book.</source>
        <translation>Skriv ut posterna i denna ordbok.</translation>
    </message>
    <message>
        <source>Cannot create phrase book &apos;%1&apos;.</source>
        <translation>Kan inte skapa ordboken &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Do you want to save phrase book &apos;%1&apos;?</source>
        <translation>Vill du spara ordboken &quot;%1&quot;?</translation>
    </message>
    <message numerus="yes">
        <source>%n unfinished message(s) left.</source>
        <translation>
            <numerusform>%n oavslutat meddelande kvar.</numerusform>
            <numerusform>%n oavslutade meddelanden kvar.</numerusform>
        </translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alla</translation>
    </message>
    <message>
        <source>Toggles the validity check of accelerators</source>
        <translation>Växlar giltighetskontroll för acceleratorer</translation>
    </message>
    <message>
        <source>Toggles visualize whitespace in editors</source>
        <translation>Växlar visualisera blanksteg i redigerare</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>Sök &amp;föregående</translation>
    </message>
    <message>
        <source>Shift+F3</source>
        <translation>Skift+F3</translation>
    </message>
</context>
<context>
    <name>MessageEditor</name>
    <message>
        <source></source>
        <comment>This is the right panel of the main window.</comment>
        <translation></translation>
    </message>
    <message>
        <source>This whole panel allows you to view and edit the translation of some source text.</source>
        <translation>Denna panel låter dig se och redigera översättningen av aktuell källtext.</translation>
    </message>
    <message>
        <source>Source text</source>
        <translation>Källtext</translation>
    </message>
    <message>
        <source>This area shows the source text.</source>
        <translation>Detta område visar källtexten.</translation>
    </message>
    <message>
        <source>Source text (Plural)</source>
        <translation>Källtext (Pluralis)</translation>
    </message>
    <message>
        <source>This area shows the plural form of the source text.</source>
        <translation>Detta område visar källtextens pluralform.</translation>
    </message>
    <message>
        <source>Developer comments</source>
        <translation>Utvecklarkommentar</translation>
    </message>
    <message>
        <source>This area shows a comment that may guide you, and the context in which the text occurs.</source>
        <translation>Detta område visar kommentarer för din vägledning, och i vilket sammanhang texten finns.</translation>
    </message>
    <message>
        <source>Here you can enter comments for your own use. They have no effect on the translated applications.</source>
        <translation>Här kan du kommentera för eget bruk. Dessa kommentarer påverkar inte det översatta programmet.</translation>
    </message>
    <message>
        <source>Translation to %1 (%2)</source>
        <translation>Översättning till %1 (%2)</translation>
    </message>
    <message>
        <source>This is where you can enter or modify the translation of the above source text.</source>
        <translation>Här kan du mata in och ändra översättningen för ovanstående källtext.</translation>
    </message>
    <message>
        <source>Translation to %1</source>
        <translation>Översättning till %1</translation>
    </message>
    <message>
        <source>Translator comments for %1</source>
        <translation>Översättarkommentar för %1</translation>
    </message>
    <message>
        <source>&apos;%1&apos;
Line: %2</source>
        <translation>&quot;%1&quot;
Rad: %2</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Completion status for %1</source>
        <translation>Slutförandestatus för %1</translation>
    </message>
    <message>
        <source>&lt;file header&gt;</source>
        <translation>&lt;file header&gt;</translation>
    </message>
    <message>
        <source>&lt;context comment&gt;</source>
        <translation>&lt;context comment&gt;</translation>
    </message>
    <message>
        <source>&lt;unnamed context&gt;</source>
        <translation>&lt;unnamed context&gt;</translation>
    </message>
    <message numerus="yes">
        <source>%n unfinished message(s) left.</source>
        <translation>
            <numerusform>%n oavslutat meddelande kvar.</numerusform>
            <numerusform>%n oavslutade meddelanden kvar.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PhraseBook</name>
    <message>
        <source>Parse error at line %1, column %2 (%3).</source>
        <translation>Tolkningsfel på rad %1, kolumn %2 (%3).</translation>
    </message>
</context>
<context>
    <name>PhraseBookBox</name>
    <message>
        <source>Edit Phrase Book</source>
        <translation>Redigera ordbok</translation>
    </message>
    <message>
        <source>This window allows you to add, modify, or delete entries in a phrase book.</source>
        <translation>Detta fönster låter dig lägga till, ändra eller ta bort poster i en ordbok.</translation>
    </message>
    <message>
        <source>&amp;Translation:</source>
        <translation>&amp;Översättning:</translation>
    </message>
    <message>
        <source>This is the phrase in the target language corresponding to the source phrase.</source>
        <translation>Detta är den fras på målspråket som motsvarar källfrasen.</translation>
    </message>
    <message>
        <source>S&amp;ource phrase:</source>
        <translation>&amp;Källfras:</translation>
    </message>
    <message>
        <source>This is a definition for the source phrase.</source>
        <translation>Detta är en definition på källfrasen.</translation>
    </message>
    <message>
        <source>This is the phrase in the source language.</source>
        <translation>Detta är en fras på källspråket.</translation>
    </message>
    <message>
        <source>&amp;Definition:</source>
        <translation>&amp;Definition:</translation>
    </message>
    <message>
        <source>Click here to add the phrase to the phrase book.</source>
        <translation>Klicka här för att lägga till frasen i ordboken.</translation>
    </message>
    <message>
        <source>&amp;New Entry</source>
        <translation>&amp;Ny post</translation>
    </message>
    <message>
        <source>Click here to remove the entry from the phrase book.</source>
        <translation>Klicka här för att ta bort posten från ordboken.</translation>
    </message>
    <message>
        <source>&amp;Remove Entry</source>
        <translation>&amp;Ta bort post</translation>
    </message>
    <message>
        <source>Settin&amp;gs...</source>
        <translation>&amp;Inställningar...</translation>
    </message>
    <message>
        <source>Click here to save the changes made.</source>
        <translation>Klicka här för att spara utförda ändringar.</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Spara</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>Klicka här för att stänga detta fönster.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <source></source>
        <comment>Go to Phrase &gt; Edit Phrase Book... The dialog that pops up is a PhraseBookBox.</comment>
        <translation></translation>
    </message>
    <message>
        <source>(New Entry)</source>
        <translation>(Ny post)</translation>
    </message>
    <message>
        <source>%1[*] - Qt Linguist</source>
        <translation>%1[*] - Qt Linguist</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <source>Cannot save phrase book &apos;%1&apos;.</source>
        <translation>Kan inte spara ordboken &quot;%1&quot;.</translation>
    </message>
</context>
<context>
    <name>PhraseModel</name>
    <message>
        <source>Source phrase</source>
        <translation>Källfras</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Översättning</translation>
    </message>
    <message>
        <source>Definition</source>
        <translation>Definition</translation>
    </message>
</context>
<context>
    <name>PhraseView</name>
    <message>
        <source>Insert</source>
        <translation>Infoga</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <source>Go to</source>
        <translation>Gå till</translation>
    </message>
    <message>
        <source>Guess from &apos;%1&apos; (%2)</source>
        <translation>Gissning från &quot;%1&quot; (%2)</translation>
    </message>
    <message>
        <source>Guess from &apos;%1&apos;</source>
        <translation>Gissning från &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Translation files (%1);;</source>
        <translation>Översättningsfiler (%1);;</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Alla filer (*)</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
</context>
<context>
    <name>SourceCodeView</name>
    <message>
        <source>&lt;i&gt;Source code not available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Källkod inte tillgänglig&lt;/i&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;File %1 not available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Filen %1 inte läsbar&lt;/i&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;File %1 not readable&lt;/i&gt;</source>
        <translation>&lt;i&gt;Filen %1 inte tillgänglig&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>Statistics</name>
    <message>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Översättning</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Källa</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Ord:</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Tecken:</translation>
    </message>
    <message>
        <source>Characters (with spaces):</source>
        <translation>Tecken (inkl. blanksteg):</translation>
    </message>
    <message>
        <source>Unfinished</source>
        <translation>Oavslutade</translation>
    </message>
    <message>
        <source>Total translatable messages:</source>
        <translation>Totalt översättningsbara meddelanden:</translation>
    </message>
    <message>
        <source>Total finished:</source>
        <translation>Totalt färdiga:</translation>
    </message>
    <message>
        <source>Without warnings:</source>
        <translation>Utan varningar:</translation>
    </message>
    <message>
        <source>With warnings:</source>
        <translation>Med varningar:</translation>
    </message>
    <message>
        <source>Unfinished:</source>
        <translation>Oavslutade:</translation>
    </message>
    <message>
        <source>Total messages including obsolete:</source>
        <translation>Totalt meddelanden inklusive föråldrade:</translation>
    </message>
</context>
<context>
    <name>TranslateDialog</name>
    <message>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation>Detta fönster låter dig söka efter text översättningsfilen.</translation>
    </message>
    <message>
        <source>Type in the text to search for.</source>
        <translation>Skriv in text att söka efter.</translation>
    </message>
    <message>
        <source>Find &amp;source text:</source>
        <translation>Sök &amp;källtext:</translation>
    </message>
    <message>
        <source>&amp;Translate to:</source>
        <translation>&amp;Översätt till:</translation>
    </message>
    <message>
        <source>Search options</source>
        <translation>Sökalternativ</translation>
    </message>
    <message>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation>Texter som &quot;TeX&quot; och &quot;tex&quot; betraktas som olika när detta är markerat.</translation>
    </message>
    <message>
        <source>Match &amp;case</source>
        <translation>Skift&amp;lägeskänslig</translation>
    </message>
    <message>
        <source>Mark new translation as &amp;finished</source>
        <translation>Markera ny översättning som sl&amp;utförd</translation>
    </message>
    <message>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation>Klicka här för att hitta nästa förekomst av den text du söker.</translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation>Sök nästa</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Översätt</translation>
    </message>
    <message>
        <source>Translate All</source>
        <translation>Översätt alla</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>Klicka här för att stänga detta fönster.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>TranslationSettingsDialog</name>
    <message>
        <source>Source language</source>
        <translation>Källspråk</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Språk</translation>
    </message>
    <message>
        <source>Country/Region</source>
        <translation>Land/Region</translation>
    </message>
    <message>
        <source>Target language</source>
        <translation>Målspråk</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <extracomment>&lt;english&gt; (&lt;endonym&gt;) (language names)</extracomment>
        <translation>%1 (%2)</translation>
    </message>
    <message>
        <source>Settings for &apos;%1&apos; - Qt Linguist</source>
        <translation>Inställningar för &quot;%1&quot; - Qt Linguist</translation>
    </message>
    <message>
        <source>Any Territory</source>
        <translation>Valfritt territorium</translation>
    </message>
</context>
</TS>
